@@ -8,15 +8,6 @@
 # Contact: Kyle Lahnakoski (kyle@lahnakoski.com)
 #
 
-"""
-# NOTE:
-
-THE self.lang[operator] PATTERN IS CASTING NEW OPERATORS TO OWN LANGUAGE;
-KEEPING Python AS# Python, ES FILTERS AS ES FILTERS, AND Painless AS
-Painless. WE COULD COPY partial_eval(), AND OTHERS, TO THIER RESPECTIVE
-LANGUAGE, BUT WE KEEP CODE HERE SO THERE IS LESS OF IT
-
-"""
 from __future__ import absolute_import, division, unicode_literals
 
 from jx_base.expressions import literal, false_op, _utils
@@ -56,10 +47,7 @@ class TrueOp(Literal):
     def missing(self):
         return FALSE
 
-    def is_true(self):
-        return TRUE
-
-    def is_false(self):
+    def invert(self):
         return FALSE
 
     def __call__(self, row=None, rownum=None, rows=None):
