@@ -8,15 +8,6 @@
 # Contact: Kyle Lahnakoski (kyle@lahnakoski.com)
 #
 
-"""
-# NOTE:
-
-THE self.lang[operator] PATTERN IS CASTING NEW OPERATORS TO OWN LANGUAGE;
-KEEPING Python AS# Python, ES FILTERS AS ES FILTERS, AND Painless AS
-Painless. WE COULD COPY partial_eval(), AND OTHERS, TO THIER RESPECTIVE
-LANGUAGE, BUT WE KEEP CODE HERE SO THERE IS LESS OF IT
-
-"""
 from __future__ import absolute_import, division, unicode_literals
 
 from jx_base.expressions import _utils, expression
@@ -25,7 +16,7 @@ from jx_base.expressions.false_op import FALSE
 from jx_base.expressions.missing_op import MissingOp
 from jx_base.language import is_op
 from jx_base.utils import get_property_name
-from mo_dots import coalesce, is_sequence, split_field
+from mo_dots import is_sequence, split_field
 from mo_dots.lists import last
 from mo_future import is_text
 from mo_json.typed_encoder import inserter_type_to_json_type
