@@ -8,15 +8,6 @@
 # Contact: Kyle Lahnakoski (kyle@lahnakoski.com)
 #
 
-"""
-# NOTE:
-
-THE self.lang[operator] PATTERN IS CASTING NEW OPERATORS TO OWN LANGUAGE;
-KEEPING Python AS# Python, ES FILTERS AS ES FILTERS, AND Painless AS
-Painless. WE COULD COPY partial_eval(), AND OTHERS, TO THIER RESPECTIVE
-LANGUAGE, BUT WE KEEP CODE HERE SO THERE IS LESS OF IT
-
-"""
 from __future__ import absolute_import, division, unicode_literals
 
 from jx_base.expressions import first_op, eq_op, not_op
@@ -32,7 +23,7 @@ from jx_base.expressions.or_op import OrOp
 from jx_base.expressions.true_op import TRUE
 from jx_base.language import is_op
 from mo_dots import coalesce
-from mo_json import OBJECT, same_json_type, merge_json_type
+from mo_json import INTEGER, NUMBER, OBJECT, NUMBER_TYPES, same_json_type, merge_json_type
 from mo_logs import Log
 
 
@@ -81,6 +72,17 @@ class WhenOp(Expression):
             )
         ].partial_eval()
 
+    def invert(self):
+        return self.lang[
+            OrOp(
+                [
+                    AndOp([self.when, self.then.invert()]),
+                    AndOp([NotOp(self.when), self.els_.invert()]),
+                ]
+            )
+        ].partial_eval()
+
+
     @simplified
     def partial_eval(self):
         when = self.lang[BooleanOp(self.when)].partial_eval()
